<?php

/**
 * @category  Storage
 * @author    Ebine Yutaka <ebine.yutaka@sabel.jp>
 */
class Test_DB_Storage_PdoSqlite extends Test_DB_Storage_Test
{
  public static function suite()
  {
    return self::createSuite("Test_DB_Storage_PdoSqlite");
  }
  
  public function testInit()
  {
    Sabel_DB_Config::add("default", Test_DB_TestConfig::getPdoSqliteConfig());
    MODEL("SblStorage")->delete();
  }
}
